"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HighlightCodeLinesPlugin = exports.MarkdownIt = exports.markdownItFactory = exports.MultilineBlockquoteRule = exports.MultilineBlockquotePlugin = void 0;
const markdown_it_1 = __importDefault(require("markdown-it"));
exports.MarkdownIt = markdown_it_1.default;
const highlight_js_1 = __importDefault(require("highlight.js"));
const markdown_it_container_1 = __importDefault(require("markdown-it-container"));
const markdown_it_abbr_1 = __importDefault(require("markdown-it-abbr"));
const markdown_it_deflist_1 = __importDefault(require("markdown-it-deflist"));
const markdown_it_emoji_1 = __importDefault(require("markdown-it-emoji"));
const markdown_it_footnote_1 = __importDefault(require("markdown-it-footnote"));
const markdown_it_mark_1 = __importDefault(require("markdown-it-mark"));
const markdown_it_sub_1 = __importDefault(require("markdown-it-sub"));
const markdown_it_sup_1 = __importDefault(require("markdown-it-sup"));
const markdown_it_anchor_1 = __importDefault(require("markdown-it-anchor"));
const markdown_it_lazy_headers_1 = __importDefault(require("markdown-it-lazy-headers"));
const markdown_it_for_inline_1 = __importDefault(require("markdown-it-for-inline"));
const markdown_it_task_lists_1 = __importDefault(require("markdown-it-task-lists"));
const simple_math_plugin_1 = require("./plugins/simple-math.plugin");
const simple_mermaid_plugin_1 = require("./plugins/simple-mermaid.plugin");
const html_filter_plugin_1 = require("./plugins/html-filter.plugin");
const multiline_blockquote_plugin_1 = require("./plugins/multiline-blockquote/multiline-blockquote.plugin");
Object.defineProperty(exports, "MultilineBlockquotePlugin", { enumerable: true, get: function () { return multiline_blockquote_plugin_1.MultilineBlockquotePlugin; } });
Object.defineProperty(exports, "MultilineBlockquoteRule", { enumerable: true, get: function () { return multiline_blockquote_plugin_1.MultilineBlockquoteRule; } });
const option_1 = require("./option");
const toc_1 = require("./plugins/toc");
const highlight_code_lines_plugin_1 = require("./plugins/highlight-code-lines.plugin");
Object.defineProperty(exports, "HighlightCodeLinesPlugin", { enumerable: true, get: function () { return highlight_code_lines_plugin_1.HighlightCodeLinesPlugin; } });
const meta_1 = require("./plugins/meta");
const mdUtils = new markdown_it_1.default().utils;
const defaultCodeHighlight = (str, lang) => {
    if (lang && highlight_js_1.default.getLanguage(lang)) {
        try {
            const result = highlight_js_1.default.highlight(lang, str, true);
            return `<pre class="hljs"><code data-lang="${result.language}">${result.value}</code></pre>`;
        }
        catch (_a) { }
    }
    return `<pre class="hljs"><code>${mdUtils.escapeHtml(str)}</code></pre>`;
};
const addLinkAttributes = [
    markdown_it_for_inline_1.default,
    'url_new_win',
    'link_open',
    (tokens, idx) => {
        const token = tokens[idx];
        const href = token.attrGet('href');
        if (!href) {
            return;
        }
        if (!href.startsWith('#')) {
            token.attrPush(['target', '_blank']);
        }
    },
];
const markdownItFactory = ({ html, codeHighlight, taskListsOption, math, disableRules, linkify: linkifyOption, } = option_1.defaultMarkdownItOption) => {
    const mdOpt = {
        html: html,
        breaks: true,
        linkify: true,
    };
    taskListsOption !== null && taskListsOption !== void 0 ? taskListsOption : (taskListsOption = option_1.defaultTaskListsOption);
    linkifyOption = Object.assign({}, option_1.defaultLinkifyOptions, linkifyOption !== null && linkifyOption !== void 0 ? linkifyOption : option_1.defaultLinkifyOptions);
    if (codeHighlight) {
        mdOpt.highlight = defaultCodeHighlight;
    }
    const md = new markdown_it_1.default(mdOpt)
        .use(markdown_it_container_1.default)
        .use(simple_mermaid_plugin_1.diagramPlugin)
        .use(markdown_it_anchor_1.default, option_1.anchorOption)
        .use(toc_1.TocPlugin)
        .use(markdown_it_abbr_1.default)
        .use(markdown_it_deflist_1.default)
        .use(markdown_it_emoji_1.default)
        .use(markdown_it_footnote_1.default)
        .use(markdown_it_mark_1.default)
        .use(markdown_it_sub_1.default)
        .use(markdown_it_sup_1.default)
        .use(highlight_code_lines_plugin_1.HighlightCodeLinesPlugin)
        .use(markdown_it_lazy_headers_1.default)
        .use(markdown_it_task_lists_1.default, taskListsOption)
        .use(html_filter_plugin_1.HtmlFilterPlugin)
        .use(...addLinkAttributes)
        .use(multiline_blockquote_plugin_1.MultilineBlockquotePlugin);
    md.block.ruler.before('hr', 'meta', meta_1.meta);
    if (math) {
        md.use(simple_math_plugin_1.simpleMathPlugin);
    }
    if (disableRules && disableRules.length > 0) {
        md.disable(disableRules);
    }
    const { normalize: defaultNormalize } = md.linkify.set(linkifyOption);
    if (linkifyOption.fuzzyLink && linkifyOption.fuzzyLinkUseHttps) {
        md.linkify.normalize = ((match) => {
            if (!match.schema) {
                match.url = `https://${match.url}`;
                return;
            }
            defaultNormalize(match);
        });
    }
    return md;
};
exports.markdownItFactory = markdownItFactory;
//# sourceMappingURL=markdown-it-factory.js.map